@@ -21,7 +21,7 @@ use APP\core\Application;
 use APP\core\Request;
 use APP\core\Services;
 use APP\facades\Repo;
-use APP\log\event\SubmissionEventLogEntry;
+use APP\mail\variables\ContextEmailVariable;
 use APP\notification\Notification;
 use APP\notification\NotificationManager;
 use APP\section\Section;
@@ -34,7 +34,6 @@ use PKP\core\Core;
 use PKP\core\PKPApplication;
 use PKP\db\DAORegistry;
 use PKP\decision\DecisionType;
-use PKP\facades\Locale;
 use PKP\handler\APIHandler;
 use PKP\log\event\PKPSubmissionEventLogEntry;
 use PKP\mail\mailables\PublicationVersionNotify;
@@ -641,8 +640,17 @@ class PKPSubmissionHandler extends APIHandler
         $mailable
             ->from($context->getData('contactEmail'), $context->getData('contactName'))
             ->recipients([$request->getUser()])
-            ->subject($emailTemplate->getLocalizedData('subject'))
-            ->body($emailTemplate->getLocalizedData('body'));
+            // The template may not exist, see pkp/pkp-lib#9217
+            ->subject($emailTemplate?->getLocalizedData('subject') ?? __('emails.submissionSavedForLater.subject'))
+            ->body($emailTemplate?->getLocalizedData('body') ?? __('emails.submissionSavedForLater.body'));
+
+        if (!$emailTemplate) {
+            $templateVariables = $mailable->getData();
+            $mailable->addData([
+                'contextName' => $templateVariables[ContextEmailVariable::CONTEXT_NAME],
+                'contextUrl' => $templateVariables[ContextEmailVariable::CONTEXT_URL],
+            ]);
+        }
 
         Mail::send($mailable);
 
@@ -721,7 +729,7 @@ class PKPSubmissionHandler extends APIHandler
                 'isTranslated' => false,
                 'dateLogged' => Core::getCurrentDate(),
                 'username' => $user->getUsername(),
-                'userFullName' => $user->getFullName(true, false, Locale::getLocale()),
+                'userFullName' => $user->getFullName(),
                 'copyrightNotice' => $context->getData('copyrightNotice'),
             ]);
 
